@@ -6,15 +6,6 @@ import json
 gTIMEOUT = 10 # seconds to wait for a response from the ESP32
 class Motor(object):
 
-    microsteppingfactor_filter=16 # run more smoothly
-    filter_pos_1 = 1000*microsteppingfactor_filter # GFP
-    filter_pos_2 = 0*microsteppingfactor_filter # AF647/SIR
-    filter_pos_3 = 500*microsteppingfactor_filter
-    filter_pos_LED = filter_pos_1 # GFP / Brightfield
-    filter_pos_init = -1250*microsteppingfactor_filter
-    filter_speed = microsteppingfactor_filter * 500
-    filter_position_now = 0
-
     # indicate if there is any motion happening
     isRunning = False
 
@@ -78,21 +69,7 @@ class Motor(object):
             self.stepSizeT = stepSize
             self.backlashT = backlash
 
-    def home_x(self):
-        r = self.home(axis="X")
-        return r
 
-    def home_y(self):
-        r = self.home(axis="Y")
-        return r
-
-    def home_z(self):
-        r = self.home(axis="Z")
-        return r
-
-    def home_xyz(self):
-        r = self.home(axis="XYZ")
-        return r
 
     def xyztTo1230(self, axis):
         axis = axis.upper()
@@ -106,32 +83,6 @@ class Motor(object):
             axis = 0
         return axis
 
-    def home(self, axis="X", timeout=gTIMEOUT, speed = 2000, direction = 1, endposrelease=500):
-        # convert X,Y,Z to 0,1,2
-        if type(axis) == str:
-            axis = self.xyztTo1230(axis)
-        if direction not in [-1,1]:
-            direction = 1
-
-        path = "/motor_act",
-
-        payload = {
-            "task": path,
-            "home":{
-                "steppers": [
-                {
-                 "stepperid": axis,
-                 "timeout":timeout,
-                 "speed":speed,
-                 "direction":direction,
-                 "endposrelease":endposrelease
-                 }]
-            }}
-
-        r = self._parent.post_json(path, payload)
-        return r
-
-
     def move_x(self, steps=100, speed=1000, is_blocking=False, is_absolute=False, is_enabled=True, timeout=gTIMEOUT):
         return self.move_axis_by_name(axis="X", steps=steps, speed=speed, is_blocking=is_blocking, is_absolute=is_absolute, is_enabled=is_enabled, timeout=timeout)
 
@@ -180,70 +131,88 @@ class Motor(object):
         r = self.move_stepper(_steps, speed=_speed, timeout=timeout, backlash=_backlash, is_blocking=is_blocking, is_absolute=is_absolute, is_enabled=is_enabled)
         return r
 
-    def init_filter(self, nSteps, speed=250, filter_axis=-1, is_blocking = True, is_enabled=False):
-        self.move_filter(steps=nSteps, speed=speed, filter_axis=filter_axis, is_blocking=is_blocking, is_enabled = is_enabled)
-        self.is_filter_init = True
-        self.filter_position_now = 0
-
-    def switch_filter(self, filter_pos=0, filter_axis=-1, timeout=20, is_filter_init=None, speed=None, is_enabled=False, is_blocking=True):
-
-        # switch off all lasers first!
-        self.set_laser(1, 0)
-        self.set_laser(2, 0)
-        self.set_laser(3, 0)
-
-        if speed is None:
-            speed = self.filter_speed
-
-        if is_filter_init is not None:
-            self.is_filter_init = is_filter_init
-        if not self.is_filter_init:
-            self.init_filter(nSteps=self.filter_pos_init, speed=speed, filter_axis=filter_axis, is_blocking = True)
-
-        # measured in steps from zero position
-        steps = filter_pos - self.filter_position_now
-        self.filter_position_now = filter_pos
-
-        self.move_filter(steps=steps, speed=speed, filter_axis=filter_axis, is_blocking=is_blocking, timeout=timeout, is_enabled=is_enabled)
-
-
-    def move_filter(self, steps=100, speed=200, filter_axis=-1, timeout=10, is_enabled=False, is_blocking=False):
-        steps_xyzt = np.zeros(4)
-        steps_xyzt[filter_axis] = steps
-        r = self.move_stepper(steps=steps_xyzt, speed=speed, timeout=timeout, is_enabled=is_enabled, is_blocking=is_blocking)
-        return r
-
     def move_forever(self, speed=(0,0,0,0), is_stop=False):
         if type(speed)==int:
             speed=(speed, speed, speed, speed)
         if len(speed)==3:
             speed = (*speed,0)
-        path = "/motor_act"
+        '''
+        {"task":"/motor_act",
+            "motor":
+            {
+                "steppers": [
+                    { "stepperid": 3, "isforever": 1, "speed": 2000}
+                ]
+            }
+        }
+        '''
+        # only consider those actions that are necessary
+        motorPropList = []
+        for iMotor in range(4):
+            if abs(speed[iMotor])>0:
+                motorProp = { "stepperid": iMotor,
+                             "isforever": int(not is_stop),
+                             "speed": speed[iMotor]}
+                motorPropList.append(motorProp)
 
+        path = "/motor_act"
         payload = {
             "task":path,
             "motor":
             {
-                "steppers": [
-                    { "stepperid": 0, "speed": speed[0], "isforver":1, "isstop":is_stop},
-                    { "stepperid": 1, "speed": speed[1], "isforver":1, "isstop":is_stop},
-                    { "stepperid": 2, "speed": speed[2], "isforver":1, "isstop":is_stop},
-                    { "stepperid": 3, "speed": speed[3], "isforver":1, "isstop":is_stop},
-                ]
+                "steppers": motorPropList
             }
         }
+
         r = self._parent.post_json(path, payload, timeout=0)
         return r
 
+
+    def stop(self, axis=None):
+        axisNumberList = []
+        if axis is None:
+            for iMotor in range(self.nMotors):
+                axisNumberList.append(iMotor)
+        else:
+            axisNumberList.append(self.xyztTo1230(axis))
+
+        motorPropList = []
+        for iMotor in axisNumberList:
+            motorProp = { "stepperid": iMotor,
+                            "isstop": True}
+            motorPropList.append(motorProp)
+
+        path = "/motor_act"
+        payload = {
+            "task":path,
+            "motor":
+            {
+                "steppers": motorPropList
+            }
+        }
+        # ensure that nothing blocks this command!
+        if self.isRunning:
+            self._parent.serial.breakCurrentCommunication()
+        r = self._parent.post_json(path, payload, getReturn=False, timeout=0)
+        return r
+
+
     def move_stepper(self, steps=(0,0,0,0), speed=(1000,1000,1000,1000), is_absolute=(False,False,False,False), timeout=1, backlash=(0,0,0,0), is_blocking=True, is_enabled=True):
         '''
         This tells the motor to run at a given speed for a specific number of steps; Multiple motors can run simultaneously
 
         XYZT => 1,2,3,0
         '''
-        if type(is_absolute)==bool:
-            is_absolute = (is_absolute,is_absolute,is_absolute,is_absolute)
 
+        # determine the axis to operate
+        axisToMove = np.where(np.abs(speed)>0)
+
+        if type(is_absolute)==bool:
+            isAbsoluteArray = np.zeros((4))
+            isAbsoluteArray[axisToMove] = is_absolute
+        else:
+            isAbsoluteArray = is_absolute
+            
         # convert single elements to array
         if type(speed)!=list and type(speed)!=tuple and type(speed)!=np.ndarray:
             speed = np.array((speed,speed,speed,speed))
@@ -258,20 +227,16 @@ class Motor(object):
                 # we want to overshoot a bit
                 steps[iMotor] = steps[iMotor] + (np.sign(steps[iMotor])*backlash[iMotor])
 
-
-        '''
         # get current position
-        pos_0 = self.get_position(0)
-        pos_1 = self.get_position(1)
-        pos_2 = self.get_position(2)
-        pos_3 = self.get_position(3)
+        #_positions = self.get_position() # x,y,z,t = 1,2,3,0
+        #pos_3, pos_0, pos_1, pos_2 = _positions[0],_positions[1],_positions[2],_positions[3]
 
         # convert to physical units
-        steps_0 = steps_0*self.stepSizeX
-        steps_1 = steps_1*self.stepSizeY
-        steps_2 = steps_2*self.stepSizeZ
-        steps_3 = steps_3*self.stepSizeT
-
+        steps[0] *= 1/self.stepSizeT
+        steps[1] *= 1/self.stepSizeX
+        steps[2] *= 1/self.stepSizeY
+        steps[3] *= 1/self.stepSizeZ
+        '''
         # check if within limits
         if pos_0+steps_0 > self.maxPosX or pos_0+steps_0 < self.minPosX:
             steps_0=0
@@ -311,11 +276,11 @@ class Motor(object):
         # only consider those actions that are necessary
         motorPropList = []
         for iMotor in range(4):
-            if is_absolute[iMotor] or abs(steps[iMotor])>0:
+            if isAbsoluteArray[iMotor] or abs(steps[iMotor])>0:
                 motorProp = { "stepperid": iMotor,
                              "position": np.int(steps[iMotor]),
                              "speed": speed[iMotor],
-                             "isabs": is_absolute[iMotor],
+                             "isabs": isAbsoluteArray[iMotor],
                              "isaccel":0}
                 motorPropList.append(motorProp)
 
@@ -334,24 +299,24 @@ class Motor(object):
 
         # drive motor
         self.isRunning = True
-        r = self._parent.post_json(path, payload, getReturn=True, timeout=timeout)
+        r = self._parent.post_json(path, payload, getReturn=is_blocking, timeout=timeout)
 
-        # wait until job has been done
-
-        '''
+        # wait until job has been done        
         time0=time.time()
-        steppersRunning = np.array(steps)>0
+        steppersRunning = np.abs(np.array(steps))>0
         if is_blocking and self._parent.serial.is_connected:
             while True:
                 time.sleep(0.05) # don'T overwhelm the CPU
                 # see if already done
                 try:
                     rMessage = self._parent.serial.serialdevice.readline().decode() # TODO: Make sure it's compatible with all motors running at the same time
+                    print(rMessage)
                 except Exception as e:
                     self._parent.logger.error(e)
                     rMessage = ""
                 # check if message contains a motor that is done already
                 if rMessage.find('isDone') >-1:
+                    ''' TODO: This only checks for one motor!'''
                     try:
                         rMessage = rMessage.split("\r")[0].replace("'", '"')
                         mMessage = json.loads(rMessage)
@@ -361,14 +326,14 @@ class Motor(object):
                                 steppersRunning[mNumber] = False
                     except:
                         pass
-
+                    
                 if np.sum(steppersRunning)==0:
                     break
 
                 if time.time()-time0>timeout:
                     break
 
-        '''
+
         # reset busy flag
         self.isRunning = False
         return r
@@ -444,17 +409,19 @@ class Motor(object):
         r = self.set_motor(stepperid = axis, isEnable=is_enable)
         return r
 
-    def get_position(self, timeout=1):
+    def get_position(self, axis=None, timeout=1):
+        # pulls all current positions from the stepper controller
         path = "/motor_get"
         payload = {
             "task":path,
-            "position":1,
+            "position":True,
         }
         r = self._parent.post_json(path, payload, timeout=timeout)
-        _position = np.array((0,0,0,0))
+        _position = np.array((0,0,0,0)) # T,X,Y,Z
+        _physicalStepSizes = np.array((self.stepSizeT, self.stepSizeX, self.stepSizeY, self.stepSizeZ))
         try:
-            for istepper in r["motor"]["steppers"]:
-                _position[istepper["stepperid"]]=istepper["position"]
+            for index, istepper in enumerate(r["motor"]["steppers"]):
+                _position[istepper["stepperid"]]=istepper["position"]*_physicalStepSizes[index]
         except Exception as e: self._parent.logger.error(e)
         return _position
 
